==> duiba-activity-service-api-0.0.1-20220408.085034-129-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/dto/PlaywayAcceptInviteDTO.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.dto;

import java.util.Date;

public class PlaywayAcceptInviteDTO {

    private Long id;
    private Long activityId;
    private Long genInviteId;
    private String playwayId;
    private Long inviter;
    private Long invitee;
    private String extra;


    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getGenInviteId() {
        return genInviteId;
    }

    public void setGenInviteId(Long genInviteId) {
        this.genInviteId = genInviteId;
    }

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public Long getInviter() {
        return inviter;
    }

    public void setInviter(Long inviter) {
        this.inviter = inviter;
    }

    public Long getInvitee() {
        return invitee;
    }

    public void setInvitee(Long invitee) {
        this.invitee = invitee;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    private Date gmtCreate;
    private Date gmtModified;

    public String getExtra() {
        return extra;
    }
}

==> duiba-activity-service-api-0.0.21-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/dto/PlaywayAcceptInviteDTO.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.dto;

import java.io.Serializable;
import java.util.Date;

public class PlaywayAcceptInviteDTO implements Serializable {

    private static final long serialVersionUID = 7228369305851420253L;

    private Long id;
    private Long activityId;
    private Long genInviteId;
    private String playwayId;
    private Long inviter;
    private Long invitee;
    private String extra;


    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getGenInviteId() {
        return genInviteId;
    }

    public void setGenInviteId(Long genInviteId) {
        this.genInviteId = genInviteId;
    }

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public Long getInviter() {
        return inviter;
    }

    public void setInviter(Long inviter) {
        this.inviter = inviter;
    }

    public Long getInvitee() {
        return invitee;
    }

    public void setInvitee(Long invitee) {
        this.invitee = invitee;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    private Date gmtCreate;
    private Date gmtModified;

    public String getExtra() {
        return extra;
    }
}
